# Agent Instructions

## Pull Request Configuration

**IMPORTANT:** This is a fork for personal use. We do not want to upstream any changes to the original repository.

When creating pull requests, they must **always** be directed to the fork repository:

**Target Repository:** https://github.com/GeorgePearse/bayesian_filters

**NEVER create PRs against:** https://github.com/rlabbe/filterpy

All development work, features, and fixes are for the fork only. Do not attempt to contribute changes back to the upstream project.
